# E-Ink Python Library
E-ink display library for waveshare screens

## Installation
```
pip install weink
```

## Usage
First look up which spec your waveshare e-ink display has
For this example I will import the 2.7 inch display.
```
from weink import epd2in7
```
